@@ -1,4 +1,4 @@
-class BadHash:
+class CustomHash:
     """__hash__ returns dict"""
 
     def __hash__(self):  # [invalid-hash-returned]
