@@ -1,3 +1,3 @@
 def show(host_id=10.11):
-    for inner_host_id, host in [[12.13, 'Venus'], [14.15, 'Mars']]:
+    for inner_host_id, host in [[12.13, "Venus"], [14.15, "Mars"]]:
         print(host_id, inner_host_id, host)
