@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Check format checker helper functions."""
 
@@ -148,9 +148,10 @@ class TestCheckSpace(CheckerTestCase):
             encoding_token = tokenize.TokenInfo(
                 tokenize.ENCODING, "utf-8", (0, 0), (0, 0), ""
             )
-            tokens = [encoding_token] + _tokenize_str(
-                "if (\n        None):\n    pass\n"
-            )
+            tokens = [
+                encoding_token,
+                *_tokenize_str("if (\n        None):\n    pass\n"),
+            ]
             self.checker.process_tokens(tokens)
 
 
