@@ -1,6 +1,6 @@
 # pylint: disable=too-few-public-methods, missing-docstring,import-error,wrong-import-position
 # pylint: disable=wrong-import-order, unnecessary-lambda, consider-using-f-string
-# pylint: disable=unnecessary-lambda-assignment, no-self-argument, unused-argument
+# pylint: disable=unnecessary-lambda-assignment, no-self-argument, unused-argument, kwarg-superseded-by-positional-arg
 
 def decorator(fun):
     """Decorator"""
@@ -265,7 +265,7 @@ CALL = lambda *args: func(*args)
 
 # Ensure `too-many-function-args` is not emitted when a function call is assigned
 # to a class attribute inside the class where the function is defined.
-# Reference: https://github.com/PyCQA/pylint/issues/6592
+# Reference: https://github.com/pylint-dev/pylint/issues/6592
 class FruitPicker:
     def _pick_fruit(fruit):
         def _print_selection(self):
@@ -278,3 +278,56 @@ class FruitPicker:
 picker = FruitPicker()
 picker.pick_apple()
 picker.pick_pear()
+
+
+def name1(apple, /, **kwargs):
+    """
+    Positional-only parameter with `**kwargs`.
+    Calling this function with the `apple` keyword should not emit
+    `redundant-keyword-arg` since it is added to `**kwargs`.
+
+    >>> name1("Red apple", apple="Green apple")
+    "Red apple"
+    {"apple": "Green apple"}
+    """
+    print(apple)
+    print(kwargs)
+
+
+name1("Red apple", apple="Green apple")
+
+
+def name2(apple, /, banana, **kwargs):
+    """
+    Positional-only parameter with positional-or-keyword parameter and `**kwargs`.
+    """
+
+
+# `banana` is redundant
+# +1:[redundant-keyword-arg]
+name2("Red apple", "Yellow banana", apple="Green apple", banana="Green banana")
+
+
+# Test `no-value-for-parameter` in the context of positional-only parameters
+
+def name3(param1, /, **kwargs): ...
+def name4(param1, /, param2, **kwargs): ...
+def name5(param1=True, /, **kwargs): ...
+def name6(param1, **kwargs): ...
+
+name3(param1=43)  # [no-value-for-parameter]
+name3(43)
+name4(1, param2=False)
+name5()
+name6(param1=43)
+
+
+# https://github.com/pylint-dev/pylint/issues/9036
+# No value for argument 'string' in staticmethod call (no-value-for-parameter)
+class Foo:
+    @staticmethod
+    def func(string):
+        return string
+
+    func(42)
+    a = func(42)
