@@ -28,4 +28,4 @@ def function():
 try:
     pass
 except function as exc:  # [catching-non-exception]
-    raise Exception from exc  # [bad-exception-cause]
+    raise Exception from exc  # [bad-exception-cause, broad-exception-raised]
