@@ -1,5 +1,5 @@
 """Regression test for issue 5770: NewType created with f-string
-See: https://github.com/PyCQA/pylint/issues/5770
+See: https://github.com/pylint-dev/pylint/issues/5770
 """
 from typing import NewType
 
