@@ -29,8 +29,12 @@ def test():
         re = None
     return re
 
-def a(): # [invalid-name]
-    """yo"""
+def a():
+    """We no longer fail 1-character names by default."""
+
+
+def A():  # [invalid-name]
+    """But we do check casing."""
 
 
 def _generate_cmdline_tests():
