@@ -11,21 +11,21 @@ def foo():
         return True
     elif arg <= arg: # [comparison-with-itself]
         return True
-    elif None == None: # [comparison-with-itself]
+    elif None == None:  # [comparison-of-constants, comparison-with-itself]
         return None
-    elif 786 == 786: # [comparison-with-itself]
+    elif 786 == 786:  # [comparison-of-constants, comparison-with-itself]
         return True
-    elif 786 is 786: # [comparison-with-itself]
+    elif 786 is 786:  # [comparison-of-constants, comparison-with-itself]
         return True
-    elif 786 is not 786: # [comparison-with-itself]
+    elif 786 is not 786:  # [comparison-of-constants, comparison-with-itself]
         return True
     elif arg is arg: # [comparison-with-itself]
         return True
     elif arg is not arg: # [comparison-with-itself]
         return True
-    elif True is True: # [comparison-with-itself]
+    elif True is True:  # [comparison-of-constants, comparison-with-itself]
         return True
-    elif 666 == 786:
+    elif 666 == 786:  # [comparison-of-constants]
         return False
     else:
         return None
