@@ -1,5 +1,5 @@
 """Check for method without self as first argument"""
-
+# pylint: disable=missing-docstring,too-few-public-methods
 
 MYSTATICMETHOD = staticmethod
 
@@ -47,3 +47,15 @@ class NoSelfArgument:
 
     def varargs_and_kwargs(*args, **kwargs):  # [no-self-argument]
         """A method without a self argument but with *args and **kwargs."""
+
+
+class Toto:
+
+    def __class_getitem__(cls, params):
+        # This is actually a special method which is always a class method.
+        # See https://www.python.org/dev/peps/pep-0560/#class-getitem
+        pass
+
+    def __class_other__(cls, params):  # [no-self-argument]
+        # This is not a special case and as such is an instance method.
+        pass
