@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 import os
 from pathlib import Path
@@ -8,8 +8,6 @@ from typing import Any, NoReturn
 from unittest import mock
 from unittest.mock import patch
 
-import pytest
-from _pytest.recwarn import WarningsRecorder
 from pytest import CaptureFixture
 
 from pylint.lint.pylinter import PyLinter
@@ -24,10 +22,8 @@ def raise_exception(*args: Any, **kwargs: Any) -> NoReturn:
 def test_crash_in_file(
     linter: PyLinter, capsys: CaptureFixture[str], tmp_path: Path
 ) -> None:
-    with pytest.warns(DeprecationWarning):
-        args = linter.load_command_line_configuration([__file__])
     linter.crash_file_path = str(tmp_path / "pylint-crash-%Y")
-    linter.check(args)
+    linter.check([__file__])
     out, err = capsys.readouterr()
     assert not out
     assert not err
@@ -37,12 +33,6 @@ def test_crash_in_file(
     assert any(m.symbol == "fatal" for m in linter.reporter.messages)
 
 
-def test_check_deprecation(linter: PyLinter, recwarn: WarningsRecorder) -> None:
-    linter.check("myfile.py")
-    msg = recwarn.pop()
-    assert "check function will only accept sequence" in str(msg)
-
-
 def test_crash_during_linting(
     linter: PyLinter, capsys: CaptureFixture[str], tmp_path: Path
 ) -> None:
