@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Puts the check_parallel system under test."""
 
@@ -10,25 +10,35 @@ from __future__ import annotations
 
 import argparse
 import os
+import sys
 from concurrent.futures import ProcessPoolExecutor
 from concurrent.futures.process import BrokenProcessPool
+from pathlib import Path
 from pickle import PickleError
+from typing import TYPE_CHECKING
+from unittest.mock import patch
 
 import dill
 import pytest
-from astroid import nodes
 
 import pylint.interfaces
 import pylint.lint.parallel
 from pylint.checkers import BaseRawFileChecker
-from pylint.lint import PyLinter
+from pylint.checkers.imports import ImportsChecker
+from pylint.lint import PyLinter, augmented_sys_path
 from pylint.lint.parallel import _worker_check_single_file as worker_check_single_file
 from pylint.lint.parallel import _worker_initialize as worker_initialize
 from pylint.lint.parallel import check_parallel
 from pylint.testutils import GenericTestReporter as Reporter
+from pylint.testutils.utils import _test_cwd
 from pylint.typing import FileItem
 from pylint.utils import LinterStats, ModuleStats
 
+if TYPE_CHECKING:
+    from unittest.mock import MagicMock
+
+    from astroid import nodes
+
 
 def _gen_file_data(idx: int = 0) -> FileItem:
     """Generates a file to use as a stream."""
@@ -173,13 +183,32 @@ class TestCheckParallelFramework:
         worker_initialize(linter=dill.dumps(linter))
         assert isinstance(pylint.lint.parallel._worker_linter, type(linter))
 
+    def test_worker_initialize_with_package_paths(self) -> None:
+        linter = PyLinter(reporter=Reporter())
+        with augmented_sys_path([]):
+            worker_initialize(
+                linter=dill.dumps(linter), extra_packages_paths=["fake-path"]
+            )
+            assert "fake-path" in sys.path
+
+    def test_worker_initialize_reregisters_custom_plugins(self) -> None:
+        linter = PyLinter(reporter=Reporter())
+        linter.load_plugin_modules(["pylint.extensions.private_import"])
+
+        pickled = dill.dumps(linter)
+        with patch(
+            "pylint.extensions.private_import.register", side_effect=AssertionError
+        ):
+            with pytest.raises(AssertionError):
+                worker_initialize(linter=pickled)
+
     @pytest.mark.needs_two_cores
     def test_worker_initialize_pickling(self) -> None:
         """Test that we can pickle objects that standard pickling in multiprocessing can't.
 
         See:
         https://stackoverflow.com/questions/8804830/python-multiprocessing-picklingerror-cant-pickle-type-function
-        https://github.com/PyCQA/pylint/pull/5584
+        https://github.com/pylint-dev/pylint/pull/5584
         """
         linter = PyLinter(reporter=Reporter())
         linter.attribute = argparse.ArgumentParser()  # type: ignore[attr-defined]
@@ -240,9 +269,10 @@ class TestCheckParallelFramework:
         linter.load_plugin_modules(["pylint.extensions.overlapping_exceptions"])
         try:
             dill.dumps(linter)
-            raise AssertionError(
-                "Plugins loaded were pickle-safe! This test needs altering"
-            )
+            # TODO: 4.0: Fix this test by raising this assertion again
+            # raise AssertionError(
+            #     "Plugins loaded were pickle-safe! This test needs altering"
+            # )
         except (KeyError, TypeError, PickleError, NotImplementedError):
             pass
 
@@ -324,7 +354,6 @@ class TestCheckParallel:
             linter,
             jobs=1,
             files=iter(single_file_container),
-            arguments=["--enable", "R9999"],
         )
         assert len(linter.get_checkers()) == 2, (
             "We should only have the 'main' and 'sequential-checker' "
@@ -353,6 +382,7 @@ class TestCheckParallel:
         # now run the regular mode of checking files and check that, in this proc, we
         # collect the right data
         filepath = [single_file_container[0][1]]  # get the filepath element
+        linter.stats = LinterStats()
         linter.check(filepath)
         assert {
             "input.similar1": {  # module is the only change from previous
@@ -390,7 +420,9 @@ class TestCheckParallel:
         # Invoke the lint process in a multi-process way, although we only specify one
         # job.
         check_parallel(
-            linter, jobs=1, files=iter(single_file_container), arguments=None
+            linter,
+            jobs=1,
+            files=iter(single_file_container),
         )
 
         assert {
@@ -504,7 +536,6 @@ class TestCheckParallel:
                     linter,
                     jobs=num_jobs,
                     files=file_infos,
-                    arguments=None,
                 )
                 stats_check_parallel = linter.stats
                 assert linter.msg_status == 0, "We should not fail the lint"
@@ -539,7 +570,7 @@ class TestCheckParallel:
 
         The intent here is to validate the reduce step: no stats should be lost.
 
-        Checks regression of https://github.com/PyCQA/pylint/issues/4118
+        Checks regression of https://github.com/pylint-dev/pylint/issues/4118
         """
 
         # define the stats we expect to get back from the runs, these should only vary
@@ -572,7 +603,6 @@ class TestCheckParallel:
                     linter,
                     jobs=num_jobs,
                     files=file_infos,
-                    arguments=None,
                 )
                 stats_check_parallel = linter.stats
         assert str(stats_single_proc.by_msg) == str(
@@ -600,5 +630,89 @@ class TestCheckParallel:
                 files=iter(single_file_container),
                 # This will trigger an exception in the initializer for the parallel jobs
                 # because arguments has to be an Iterable.
-                arguments=1,  # type: ignore[arg-type]
+                extra_packages_paths=1,  # type: ignore[arg-type]
             )
+
+    @pytest.mark.needs_two_cores
+    def test_cyclic_import_parallel(self) -> None:
+        tests_dir = Path("tests")
+        package_path = Path("input") / "func_w0401_package"
+        linter = PyLinter(reporter=Reporter())
+        linter.register_checker(ImportsChecker(linter))
+
+        with _test_cwd(tests_dir):
+            check_parallel(
+                linter,
+                jobs=2,
+                files=[
+                    FileItem(
+                        name="input.func_w0401_package.all_the_things",
+                        filepath=str(package_path / "all_the_things.py"),
+                        modpath="input.func_w0401_package",
+                    ),
+                    FileItem(
+                        name="input.func_w0401_package.thing2",
+                        filepath=str(package_path / "thing2.py"),
+                        modpath="input.func_w0401_package",
+                    ),
+                ],
+            )
+
+        assert "cyclic-import" in linter.stats.by_msg
+
+    @pytest.mark.needs_two_cores
+    @patch("pylint.checkers.imports.ImportsChecker.close")
+    def test_cyclic_import_parallel_disabled_globally(self, mock: MagicMock) -> None:
+        tests_dir = Path("tests")
+        package_path = Path("input") / "func_w0401_package"
+        linter = PyLinter(reporter=Reporter())
+        linter.register_checker(ImportsChecker(linter))
+        linter.disable("cyclic-import")
+
+        with _test_cwd(tests_dir):
+            check_parallel(
+                linter,
+                jobs=2,
+                files=[
+                    FileItem(
+                        name="input.func_w0401_package.all_the_things",
+                        filepath=str(package_path / "all_the_things.py"),
+                        modpath="input.func_w0401_package",
+                    ),
+                    FileItem(
+                        name="input.func_w0401_package.thing2",
+                        filepath=str(package_path / "thing2.py"),
+                        modpath="input.func_w0401_package",
+                    ),
+                ],
+            )
+
+        mock.assert_not_called()
+        assert "cyclic-import" not in linter.stats.by_msg
+
+    @pytest.mark.needs_two_cores
+    def test_cyclic_import_parallel_disabled_locally(self) -> None:
+        tests_dir = Path("tests")
+        package_path = Path("input") / "func_noerror_cycle"
+        linter = PyLinter(reporter=Reporter())
+        linter.register_checker(ImportsChecker(linter))
+
+        with _test_cwd(tests_dir):
+            check_parallel(
+                linter,
+                jobs=2,
+                files=[
+                    FileItem(
+                        name="input.func_noerror_cycle.a",
+                        filepath=str(package_path / "a.py"),
+                        modpath="input.func_noerror_cycle",
+                    ),
+                    FileItem(
+                        name="input.func_noerror_cycle.b",
+                        filepath=str(package_path / "b.py"),
+                        modpath="input.func_noerror_cycle",
+                    ),
+                ],
+            )
+
+        assert "cyclic-import" not in linter.stats.by_msg
