@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Functional/non regression tests for pylint."""
 
@@ -72,7 +72,7 @@ class LintTestUsingModule:
         try:
             self.linter.check(tocheck)
         except Exception as ex:
-            print(f"Exception: {ex} in {tocheck}:: {'‚ '.join(ex.args)}")
+            print(f"Exception: {ex} in {tocheck}:: {', '.join(ex.args)}")
             # This is legacy code we're trying to remove, not worth it to type correctly
             ex.file = tocheck  # type: ignore[attr-defined]
             print(ex)
@@ -114,9 +114,9 @@ def gen_tests(
     if filter_rgx:
         is_to_run = re.compile(filter_rgx).search
     else:
-        is_to_run = (
-            lambda x: 1  # type: ignore[assignment,misc] # pylint: disable=unnecessary-lambda-assignment
-        )  # noqa: E731 We're going to throw all this anyway
+        is_to_run = (  # noqa: E731, We're going to throw all this anyway
+            lambda x: 1  # type: ignore[assignment] # pylint: disable=unnecessary-lambda-assignment
+        )
     tests: list[tuple[str, str, list[tuple[str, str]]]] = []
     for module_file, messages_file in _get_tests_info(INPUT_DIR, MSG_DIR, "func_", ""):
         if not is_to_run(module_file) or module_file.endswith((".pyc", "$py.class")):
