@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 from __future__ import annotations
 
@@ -82,6 +82,23 @@ class TestSimilarCodeChecker:
             expected_output=expected_output,
         )
 
+    @pytest.mark.needs_two_cores
+    def test_duplicate_code_parallel(self) -> None:
+        path = join(DATA, "raw_strings_all")
+        expected_output = "Similar lines in 2 files"
+        self._test_output(
+            [
+                path,
+                "--disable=all",
+                "--enable=duplicate-code",
+                "--ignore-imports=no",
+                "--ignore-signatures=no",
+                "--min-similarity-lines=4",
+                "--jobs=2",
+            ],
+            expected_output=expected_output,
+        )
+
     def test_duplicate_code_raw_strings_disable_file(self) -> None:
         """Tests disabling duplicate-code at the file level in a single file."""
         path = join(DATA, "raw_strings_disable_file")
@@ -207,7 +224,8 @@ class TestSimilarCodeChecker:
         )
 
     def test_duplicate_code_raw_strings_disable_scope_function(self) -> None:
-        """Tests disabling duplicate-code at an inner scope level with another scope with similarity."""
+        """Tests disabling duplicate-code at an inner scope level with another scope with
+        similarity."""
         path = join(DATA, "raw_strings_disable_scope_second_function")
         expected_output = "Similar lines in 2 files"
         self._test_output(
@@ -246,3 +264,18 @@ class TestSimilarCodeChecker:
             exit=False,
         )
         assert not runner.linter.stats.by_msg
+
+    def test_conditional_imports(self) -> None:
+        """Tests enabling ignore-imports with conditional imports works correctly."""
+        path = join(DATA, "ignore_conditional_imports")
+        expected_output = "==ignore_conditional_imports.file_one:[2:4]"
+        self._test_output(
+            [
+                path,
+                "-e=duplicate-code",
+                "-d=unused-import,C",
+                "--ignore-imports=y",
+                "--min-similarity-lines=1",
+            ],
+            expected_output=expected_output,
+        )
